/*= R&S SMB Signal Generator Include File ===================================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library. 									 */
/*===========================================================================*/

#ifndef __RSSGS_HEADER
#define __RSSGS_HEADER

#include "visaabstraction.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif
/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8                   (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9                   (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10                  (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11                  (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12                  (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13                  (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14                  (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15                  (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSSGS_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSSGS_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSGS_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSGS_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSGS_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSGS_ERROR_CALIBRATION_FAILED              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSSGS_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE   (VI_ERROR_INSTR_OFFSET + 0xF6L)
/* Add instrument driver specific warning codes here */
#define RSSGS_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)


/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/

#define RSSGS_OPERATION_MODE_NORMAL 0
#define RSSGS_OPERATION_MODE_BBY    1
	
#define RSSGS_REMOTE_OPER_MODE_STD 0
#define RSSGS_REMOTE_OPER_MODE_EXT 1
    
#define RSSGS_SOURCE_INT    0
#define RSSGS_SOURCE_EXT    1
    
#define RSSGS_LO_OUTPUT_REF     0
#define RSSGS_LO_OUTPUT_LO      1
#define RSSGS_LO_OUTPUT_OFF     2
    
#define RSSGS_ROSC_EXT_REF_FREQ_EF10M   0
#define RSSGS_ROSC_EXT_REF_FREQ_EF100M  1
#define RSSGS_ROSC_EXT_REF_FREQ_EF1000M 2

#define RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE   0
#define RSSGS_ROSC_EXT_SYNC_BWIDTH_NARROW  1

#define RSSGS_CAL_ROSC_DATAMODE_FACTORY   0
#define RSSGS_CAL_ROSC_DATAMODE_CUSTOM    1
    
#define RSSGS_LEVEL_MODE_AUTO 0
#define RSSGS_LEVEL_MODE_LNO  1
#define RSSGS_LEVEL_MODE_LDIS 2
    
#define RSSGS_LEVEL_SETT_CHARACT_AUTO 0
#define RSSGS_LEVEL_SETT_CHARACT_UNIN 1
#define RSSGS_LEVEL_SETT_CHARACT_MON  2
#define RSSGS_LEVEL_SETT_CHARACT_CWSW 3
#define RSSGS_LEVEL_SETT_CHARACT_USER 4	
    
#define RSSGS_LEVEL_POW_ON_OFF  0
#define RSSGS_LEVEL_POW_ON_UNCH 1
    
#define RSSGS_LEVEL_ALC_STATE_ONT  0
#define RSSGS_LEVEL_ALC_STATE_ON   1
#define RSSGS_LEVEL_ALC_STATE_OFFT 2

#define RSSGS_LEVEL_ALC_DETECTOR_SENSITIVITY_OFF 0
#define RSSGS_LEVEL_ALC_DETECTOR_SENSITIVITY_LOW 1
#define RSSGS_LEVEL_ALC_DETECTOR_SENSITIVITY_MED 2
#define RSSGS_LEVEL_ALC_DETECTOR_SENSITIVITY_HIGH 3

#define RSSGS_LEVEL_ATT_RFOFF_MODE_FIXED 0
#define RSSGS_LEVEL_ATT_RFOFF_MODE_MAX 1

    
#define RSSGS_SYSTEM_INCOMPLETE 0
#define RSSGS_SYSTEM_COMPLETE   1
    
#define RSSGS_UNIT_ANGLE_DEG 0
#define RSSGS_UNIT_ANGLE_RAD 1
    
#define RSSGS_UNIT_POWER_V   0
#define RSSGS_UNIT_POWER_DBM 1
    
#define RSSGS_UNIT_VELOCITY_MPS 0
#define RSSGS_UNIT_VELOCITY_KMH 1
#define RSSGS_UNIT_VELOCITY_MPH 2
    
#define RSSGS_IP_ADDRESS_MODE_AUTO 0
#define RSSGS_IP_ADDRESS_MODE_STAT 1
    
#define RSSGS_TEST_COMMAND_SSYN       0
#define RSSGS_TEST_COMMAND_SSYNEX     1
#define RSSGS_TEST_COMMAND_IQOP3      2
#define RSSGS_TEST_COMMAND_IQOP6      3
#define RSSGS_TEST_COMMAND_SATT3      4
#define RSSGS_TEST_COMMAND_SATT6      5
#define RSSGS_TEST_COMMAND_BBINS      6
#define RSSGS_TEST_COMMAND_DIRECTLAST 7
    
#define RSSGS_HCOPY_AUTO_FILE_DAY    0
#define RSSGS_HCOPY_AUTO_FILE_MONTH  1
#define RSSGS_HCOPY_AUTO_FILE_YEAR   2

#define RSSGS_ROSC_REF_FREQ_OF10M      0
#define RSSGS_ROSC_REF_FREQ_OF100M     1
#define RSSGS_ROSC_REF_FREQ_OF1000M    2
#define RSSGS_ROSC_REF_FREQ_OFF		   3
    
#define RSSGS_LEVEL_ATT_ON_FIX 0
#define RSSGS_LEVEL_ATT_ON_MAX 1    
    
#define RSSGS_FORMAT_DATA_ASCII 0
#define RSSGS_FORMAT_DATA_PACK  1

#define RSSGS_REGISTER_OPERATION    0
#define RSSGS_REGISTER_QUESTIONABLE 1

#define RSSGS_REGISTER_COND   0
#define RSSGS_REGISTER_EVENT  1
#define RSSGS_REGISTER_ENABLE 2
#define RSSGS_REGISTER_NTR    3
#define RSSGS_REGISTER_PTR    4
    
#define RSSGS_TERMINATOR_MODE_EOI  0
#define RSSGS_TERMINATOR_MODE_STAN 1    

#define RSSGS_RF_ATT_MODE_AUTO 0
#define RSSGS_RF_ATT_MODE_FIX  1
#define RSSGS_RF_ATT_MODE_APAS 2

#define  RSSGS_TRG_CON_OP_MODE_IN             0         
#define  RSSGS_TRG_CON_OP_MODE_LO             1      
#define  RSSGS_TRG_CON_OP_MODE_MEASLATENCY    2
#define  RSSGS_TRG_CON_OP_MODE_MEASMSGARRIVED 3
#define  RSSGS_TRG_CON_OP_MODE_HI             4
#define  RSSGS_TRG_CON_OP_MODE_FBFAULT        5
#define  RSSGS_TRG_CON_OP_MODE_SIGNALVALID    6
#define  RSSGS_TRG_CON_OP_MODE_EXTOUT1        7
#define  RSSGS_TRG_CON_OP_MODE_EXTOUT2        8
#define  RSSGS_TRG_CON_OP_MODE_BLANK          9
#define  RSSGS_TRG_CON_OP_MODE_SIGNALNVALID   10
#define  RSSGS_TRG_CON_OP_MODE_PULMEXT        11
#define  RSSGS_TRG_CON_OP_MODE_PULSVIDEOOUT   12
#define  RSSGS_TRG_CON_OP_MODE_PULMEXTTRIG    13

#define RSSGS_DIAG_MMAC_BAR_SCOM 0
#define RSSGS_DIAG_MMAC_BAR_RF   1
	
#define RSSGS_VAL_ASSEMBLY_INDEX_COMMON     0
#define RSSGS_VAL_ASSEMBLY_INDEX_RF	      	1
	
#define RSSGS_VAL_OPTION_INDEX_HARDWARE		0
#define RSSGS_VAL_OPTION_INDEX_SOFTWARE		1
	
#define RSSGS_ECO_MODE_OFF 0
#define RSSGS_ECO_MODE_EM1 1
	
#define RSSGS_LEVEL_ALC_DENSITIVITY_OFF  0
#define RSSGS_LEVEL_ALC_DENSITIVITY_ON   1
#define RSSGS_LEVEL_ALC_DENSITIVITY_LOW  2
#define RSSGS_LEVEL_ALC_DENSITIVITY_HIGH 3

#define RSSGS_VAL_SENSE_POWER_DISPLAY_AVERAGE  0
#define RSSGS_VAL_SENSE_POWER_DISPLAY_PEAK     1

#define RSSGS_VAL_SENSE_POWER_SOURCE_RF    0
#define RSSGS_VAL_SENSE_POWER_SOURCE_USER  1

#define RSSGS_VAL_SENSE_POWER_FILTER_TYPE_AUTO  0
#define RSSGS_VAL_SENSE_POWER_FILTER_TYPE_USER  1
#define RSSGS_VAL_SENSE_POWER_FILTER_TYPE_NSR   2

#define RSSGS_SENSE_POWER_UNIT_DBM   0
#define RSSGS_SENSE_POWER_UNIT_DBUV  1
#define RSSGS_SENSE_POWER_UNIT_WATT  2

#define RSSGS_SENSE_POWER_PERM_PRIOR_AVER  0
#define RSSGS_SENSE_POWER_PERM_PRIOR_PEAK  1

/* --- Set PULM Polarity -------------------------------------------------- */

#define RSSGS_PULM_POLARITY_NORMAL                          0
#define RSSGS_PULM_POLARITY_INVERTED                        1

/* --- Set PULM Source ---------------------------------------------------- */

#define RSSGS_PULM_SOURCE_INTERNAL                          0
#define RSSGS_PULM_SOURCE_EXTERNAL                          1

/* --- Set PULM Trigger Mode ---------------------------------------------- */

#define RSSGS_PULM_TRIGGER_MODE_AUTO                        0
#define RSSGS_PULM_TRIGGER_MODE_EXTERNAL                    1
#define RSSGS_PULM_TRIGGER_MODE_EGATE                       2
	
/* --- Pulse Modulation Mode ----------------------------------------------- */     

#define RSSGS_PULM_MODE_SING                                0
#define RSSGS_PULM_MODE_DOUB                                1

/* ---  PULM External Input Impedance  ------------------------------------- */     
	   
#define RSSGS_PULM_EXT_TRIG_IMPEDANCE_50  	0
#define RSSGS_PULM_EXT_TRIG_IMPEDANCE_10K 	1
	
/* --- PULM External Trigger Slope  ---------------------------------------- */ 

#define RSSGS_PULM_EXT_TRIG_SLOPE_POS 	0
#define RSSGS_PULM_EXT_TRIG_SLOPE_NEG 	1
	
/* --- Serial Baud Rate ----------------------------------------------- */     
#define RSSGS_SERIAL_BAUDRATE_2400                          0
#define RSSGS_SERIAL_BAUDRATE_4800                          1
#define RSSGS_SERIAL_BAUDRATE_9600                          2
#define RSSGS_SERIAL_BAUDRATE_19200                         3
#define RSSGS_SERIAL_BAUDRATE_38400                         4
#define RSSGS_SERIAL_BAUDRATE_57600                         5
#define RSSGS_SERIAL_BAUDRATE_115200                        6

/* --- Serial Parity ----------------------------------------------- */     
#define RSSGS_SERIAL_PARITY_NONE                            0
#define RSSGS_SERIAL_PARITY_ODD                             1
#define RSSGS_SERIAL_PARITY_EVEN                            2

/* --- Serial Stop Bits ----------------------------------------------- */     
#define RSSGS_SERIAL_STOPBITS_1                             0
#define RSSGS_SERIAL_STOPBITS_2                             1

#define RSSGS_DEXC_MODE_IMPORT 								0
#define RSSGS_DEXC_MODE_EXPORT 								1

#define RSSGS_DEXC_ASCII_SOURCE_FILE_EXT_TXT 				0
#define RSSGS_DEXC_ASCII_SOURCE_FILE_EXT_CSV 				1
	
#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_TAB   		0
#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SEM   		1
#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_COMMA 		2
#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SPACE 		3

#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_DOT   	0
#define RSSGS_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_COMMA 	1

#define RSSGS_FORMAT_STATUS_REGISTER_DATA_ASCII 			0
#define RSSGS_FORMAT_STATUS_REGISTER_DATA_BIN   			1
#define RSSGS_FORMAT_STATUS_REGISTER_DATA_HEX   			2
#define RSSGS_FORMAT_STATUS_REGISTER_DATA_OCT   			3

#define RSSGS_FORMAT_BYTE_ORDER_NORMAL  					0
#define RSSGS_FORMAT_BYTE_ORDER_SWAPPED 					1



ViStatus _VI_FUNC rssgs_init (ViRsrc resourceName, ViBoolean IDQuery,
                 ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rssgs_SetFrequencyAndLevel (ViSession instrumentHandle,
                                 ViReal64 frequency, ViReal64 level);
ViStatus _VI_FUNC rssgs_UseFastSettings (ViSession instrumentHandle,
                            ViBoolean fastEnabled,
                            ViBoolean asynchronousEnabled);
ViStatus _VI_FUNC rssgs_GetFastSettings (ViSession instrumentHandle,
                            ViPBoolean enableFast, 
                            ViPBoolean enableAsynchronous);
ViStatus _VI_FUNC rssgs_FastSync (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_SetRFState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssgs_GetRFState (ViSession instrumentHandle, ViBoolean* state);

ViStatus _VI_FUNC rssgs_GetRFNumberofPaths (ViSession instrumentHandle,
                               ViInt32 *paths);

ViStatus _VI_FUNC rssgs_SetRFAttenuatorMode (ViSession instrumentHandle,
                                ViInt32 attenuatorMode);
ViStatus _VI_FUNC rssgs_GetRFAttenuatorMode (ViSession instrumentHandle,
                                ViInt32* attenuatorMode);
ViStatus _VI_FUNC rssgs_SetOperationMode (ViSession instrumentHandle,
                             ViInt32 operationMode);
ViStatus _VI_FUNC rssgs_GetOperationMode (ViSession instrumentHandle,
                             ViInt32* operationMode);
ViStatus _VI_FUNC rssgs_ConfigureFrequencyLocalOscillator
(ViSession instrumentHandle, ViInt32 source, ViInt32 output);
ViStatus _VI_FUNC rssgs_SetFrequency (ViSession instrumentHandle,
                         ViReal64 frequency);
ViStatus _VI_FUNC rssgs_GetFrequency (ViSession instrumentHandle,
                         ViReal64* frequency);
ViStatus _VI_FUNC rssgs_SetFrequencyOffset (ViSession instrumentHandle,
                         ViReal64 offset);
ViStatus _VI_FUNC rssgs_GetFrequencyOffset (ViSession instrumentHandle,
                         ViReal64* offset);
ViStatus _VI_FUNC rssgs_SetFrequencyDeltaPhase (ViSession instrumentHandle,
                                   ViReal64 deltaPhase);
ViStatus _VI_FUNC rssgs_GetFrequencyDeltaPhase (ViSession instrumentHandle,
                                   ViReal64* deltaPhase);
ViStatus _VI_FUNC rssgs_SetFrequencyDeltaPhaseAsCurrent
(ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_SetFrequencyLocalOscillatorSource
(ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssgs_GetFrequencyLocalOscillatorSource
(ViSession instrumentHandle, ViInt32* source);
ViStatus _VI_FUNC rssgs_SetFrequencyLocalOscillatorOutput
(ViSession instrumentHandle, ViInt32 output);
ViStatus _VI_FUNC rssgs_GetFrequencyLocalOscillatorOutput
(ViSession instrumentHandle, ViInt32* output);
ViStatus _VI_FUNC rssgs_ConfigureReferenceOscillator (ViSession instrumentHandle,
                                         ViInt32 source,
                                         ViInt32 referenceFrequency,
                                         ViInt32 externalReferenceFrequency,
                                         ViInt32 localOscillatorSource,
                                         ViInt32 localOscillatorOutput);
ViStatus _VI_FUNC rssgs_SetROSCSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssgs_GetROSCSource (ViSession instrumentHandle, ViInt32* source);
ViStatus _VI_FUNC rssgs_SetROSCReferenceOutputFrequency (ViSession instrumentHandle,
                                            ViInt32 referenceFrequency);
ViStatus _VI_FUNC rssgs_GetROSCReferenceOutputFrequency (ViSession instrumentHandle,
                                            ViInt32* referenceFrequency);
ViStatus _VI_FUNC rssgs_SetROSCExternalReferenceFrequency
(ViSession instrumentHandle, ViInt32 externalReferenceFrequency);
ViStatus _VI_FUNC rssgs_GetROSCExternalReferenceFrequency
(ViSession instrumentHandle, ViInt32* externalReferenceFrequency);
ViStatus _VI_FUNC rssgs_SetROSCExternalSyncBandwidth (ViSession instrumentHandle,
                                         ViInt32 synchronizationBandwidth);
ViStatus _VI_FUNC rssgs_GetROSCExternalSyncBandwidth (ViSession instrumentHandle,
                                         ViInt32* synchronizationBandwidth);
ViStatus _VI_FUNC rssgs_SetROSCCalibrationData (ViSession instrumentHandle,
                                   ViReal64 data);
ViStatus _VI_FUNC rssgs_GetROSCCalibrationData (ViSession instrumentHandle,
                                   ViReal64* data);

ViStatus _VI_FUNC rssgs_SetROSCCalibrationDataMode (ViSession instrumentHandle, 
                                       ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetROSCCalibrationDataMode (ViSession instrumentHandle, 
                                       ViInt32* mode);


ViStatus _VI_FUNC rssgs_SetROSCAdjustmentActive (ViSession instrumentHandle,
                                    ViBoolean adjustmentActive);
ViStatus _VI_FUNC rssgs_GetROSCAdjustmentActive (ViSession instrumentHandle,
                                    ViBoolean* adjustmentActive);
ViStatus _VI_FUNC rssgs_SetROSCAdjustmentValue (ViSession instrumentHandle,
                                   ViInt32 adjustmentValue);
ViStatus _VI_FUNC rssgs_GetROSCAdjustmentValue (ViSession instrumentHandle,
                                   ViInt32* adjustmentValue);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensorDisplay (ViSession instrumentHandle,
                                                     ViInt32 sensor,
													 ViInt32 trace,
                                                     ViBoolean permanentDisplay,
                                                     ViInt32 priority);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensorZero (ViSession instrumentHandle,
                                                  ViInt32 sensor);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensorSource (ViSession instrumentHandle,
                                                    ViInt32 sensor,
                                                    ViInt32 source);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensor (ViSession instrumentHandle,
                                              ViInt32 sensor,
                                              ViBoolean levelOffsetState,
                                              ViReal64 levelOffset,
                                              ViInt32 filter,
                                              ViBoolean SParameter,
                                              ViBoolean logging);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensorApertureTime (ViSession instrumentHandle,
                                                          ViInt32 sensor,
                                                          ViBoolean defaultTime,
                                                          ViReal64 apertureTime);

ViStatus _VI_FUNC rssgs_ConfigurePowerSensorSense (ViSession instrumentHandle,
                                                  ViInt32 sensor,
                                                  ViBoolean initPowerMeas,
                                                  ViInt32 unit,
                                                  ViReal64 frequency);

ViStatus _VI_FUNC rssgs_SetInitiatePowerMeasurement (ViSession instrumentHandle,
                                                     ViInt32 sensor,
                                                     ViBoolean initPowerMeas);

ViStatus _VI_FUNC rssgs_GetInitiatePowerMeasurement (ViSession instrumentHandle,
                                                     ViInt32 sensor,
                                                     ViBoolean *initPowerMeas);

ViStatus _VI_FUNC rssgs_SetPowerUseSParameters (ViSession instrumentHandle,
                                                ViInt32 sensor,
                                                ViBoolean useSParameters);

ViStatus _VI_FUNC rssgs_GetPowerUseSParameters (ViSession instrumentHandle,
                                                ViInt32 sensor,
                                                ViBoolean *useSParameters);

ViStatus _VI_FUNC rssgs_SetPowerLoggingState (ViSession instrumentHandle,
                                              ViInt32 sensor, ViBoolean logging);

ViStatus _VI_FUNC rssgs_GetPowerLoggingState (ViSession instrumentHandle,
                                              ViInt32 sensor, ViBoolean *logging);

ViStatus _VI_FUNC rssgs_SetPowerDefaultTime (ViSession instrumentHandle,
                                             ViInt32 sensor,
                                             ViBoolean defaultTime);

ViStatus _VI_FUNC rssgs_GetPowerDefaultTime (ViSession instrumentHandle,
                                             ViInt32 sensor,
                                             ViBoolean *defaultTime);

ViStatus _VI_FUNC rssgs_SetPowerApertureTime (ViSession instrumentHandle,
                                              ViInt32 sensor,
                                              ViReal64 apertureTime);

ViStatus _VI_FUNC rssgs_GetPowerApertureTime (ViSession instrumentHandle,
                                              ViInt32 sensor,
                                              ViReal64 *apertureTime);

ViStatus _VI_FUNC rssgs_SetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sensor, ViReal64 frequency);

ViStatus _VI_FUNC rssgs_GetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sensor, ViReal64 *frequency);

ViStatus _VI_FUNC rssgs_SetPowerOffset (ViSession instrumentHandle,
                                        ViInt32 sensor, ViReal64 offset);

ViStatus _VI_FUNC rssgs_GetPowerOffset (ViSession instrumentHandle,
                                        ViInt32 sensor, ViReal64 *offset);

ViStatus _VI_FUNC rssgs_SetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sensor,
                                             ViBoolean offsetState);

ViStatus _VI_FUNC rssgs_GetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sensor,
                                             ViBoolean *offsetState);

ViStatus _VI_FUNC rssgs_SetPowerSensorUnit (ViSession instrumentHandle, ViInt32 sensor,
                                      ViInt32 unit);

ViStatus _VI_FUNC rssgs_GetPowerSensorUnit (ViSession instrumentHandle, ViInt32 sensor,
                                            ViInt32 *unit);

ViStatus _VI_FUNC rssgs_SetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sensor,
                                                       ViBoolean permanentDisplay);

ViStatus _VI_FUNC rssgs_GetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sensor,
                                                       ViBoolean *permanentDisplay);

ViStatus _VI_FUNC rssgs_SetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 trace,
                                                          ViInt32 priority);

ViStatus _VI_FUNC rssgs_GetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 trace,
                                                          ViInt32 *priority);

ViStatus _VI_FUNC rssgs_ConfigurePowerFilter (ViSession instrumentHandle,
                                              ViInt32 sensor, ViInt32 filterMode,
                                              ViReal64 noiseContent,
                                              ViReal64 timeout);

ViStatus _VI_FUNC rssgs_SetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sensor,
                                              ViInt32 filterLength);

ViStatus _VI_FUNC rssgs_GetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sensor,
                                              ViInt32 *filterLength);

ViStatus _VI_FUNC rssgs_SetPowerFilterMode (ViSession instrumentHandle,
                                            ViInt32 sensor, ViInt32 filterMode);

ViStatus _VI_FUNC rssgs_GetPowerFilterMode (ViSession instrumentHandle,
                                            ViInt32 sensor, ViInt32 *filterMode);

ViStatus _VI_FUNC rssgs_SetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sensor,
                                                         ViReal64 noiseContent);

ViStatus _VI_FUNC rssgs_GetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sensor,
                                                         ViReal64 *noiseContent);

ViStatus _VI_FUNC rssgs_SetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sensor,
                                                         ViReal64 timeout);

ViStatus _VI_FUNC rssgs_GetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sensor,
                                                         ViReal64 *timeout);

ViStatus _VI_FUNC rssgs_GetPowerFilterLengthAuto (ViSession instrumentHandle,
                                                  ViInt32 sensor,
                                                  ViInt32 *filterLengthAuto);

ViStatus _VI_FUNC rssgs_PowerFilterSearchOnce (ViSession instrumentHandle,
                                               ViInt32 sensor);

ViStatus _VI_FUNC rssgs_PowerSensorDevice (ViSession instrumentHandle,
                                           ViInt32 sensor, ViInt32 *device);

ViStatus _VI_FUNC rssgs_PowerSensorType (ViSession instrumentHandle,
                                         ViInt32 sensor, ViChar type[]);

ViStatus _VI_FUNC rssgs_PowerReadPower (ViSession instrumentHandle, ViInt32 read,
                                        ViReal64 *power);

ViStatus _VI_FUNC rssgs_PowerSensorVersion (ViSession instrumentHandle,
                                            ViInt32 sensor, ViChar version[]);

ViStatus _VI_FUNC rssgs_PowerSensorSerialNumber (ViSession instrumentHandle,
                                                 ViInt32 sensor,
                                                 ViChar serialNumber[]);

ViStatus _VI_FUNC rssgs_SetLevel (ViSession instrumentHandle, ViReal64 level);
ViStatus _VI_FUNC rssgs_GetLevel(ViSession instrumentHandle, ViReal64* level);
ViStatus _VI_FUNC rssgs_SetLevelOffset(ViSession instrumentHandle, ViReal64 offset);
ViStatus _VI_FUNC rssgs_GetLevelOffset(ViSession instrumentHandle, ViReal64* offset);

ViStatus _VI_FUNC rssgs_ConfigureLevelSettings (ViSession instrumentHandle,
                                   ViInt32 mode,
                                   ViInt32 settingCharacteristic,
                                   ViReal64 limit);
ViStatus _VI_FUNC rssgs_SetLevelMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetLevelMode (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rssgs_SetLevelSettingCharacteristic (ViSession instrumentHandle,
                                          ViInt32 settingCharacteristic);
ViStatus _VI_FUNC rssgs_GetLevelSettingCharacteristic (ViSession instrumentHandle,
                                          ViInt32* settingCharacteristic);

ViStatus _VI_FUNC rssgs_GetPeakEnvelopePower (ViSession instrumentHandle,
                                 ViReal64 *PEP);

ViStatus _VI_FUNC rssgs_GetLevelLowerRange (ViSession instrumentHandle,
                               ViReal64 *LowerLimit);

ViStatus _VI_FUNC rssgs_GetLevelUpperRange (ViSession instrumentHandle,
                               ViReal64 *UpperLimit);

ViStatus _VI_FUNC rssgs_SetLevelLimit (ViSession instrumentHandle, ViReal64 limit);
ViStatus _VI_FUNC rssgs_GetLevelLimit (ViSession instrumentHandle, ViReal64* limit);
ViStatus _VI_FUNC rssgs_SetLevelPowerOnState (ViSession instrumentHandle,
                                 ViInt32 powerOnState);
ViStatus _VI_FUNC rssgs_GetLevelPowerOnState (ViSession instrumentHandle,
                                 ViInt32* powerOnState);
ViStatus _VI_FUNC rssgs_SetLevelALCState (ViSession instrumentHandle,
                             ViInt32 state);
ViStatus _VI_FUNC rssgs_GetLevelALCState (ViSession instrumentHandle,
                             ViInt32* state);

ViStatus _VI_FUNC rssgs_SetLevelALCDensitivity (ViSession instrumentHandle,
                                   ViInt32 state);
ViStatus _VI_FUNC rssgs_GetLevelALCDensitivity (ViSession instrumentHandle,
                                   ViInt32 *state);




ViStatus _VI_FUNC rssgs_ReadjustLevelALC (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_SetAttenuatorModeAfterOn (ViSession instrumentHandle,
                                     ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetAttenuatorModeAfterOn (ViSession instrumentHandle,
                                     ViInt32* mode);
ViStatus _VI_FUNC rssgs_SetAttenuatorSwitchOverOffset (ViSession instrumentHandle,
                                          ViReal64 offset);
ViStatus _VI_FUNC rssgs_GetAttenuatorSwitchOverOffset (ViSession instrumentHandle,
                                          ViReal64* offset);
ViStatus _VI_FUNC rssgs_GetAttenuatorLowerRange (ViSession instrumentHandle,
                                    ViReal64* attenuatorLowerRange);
ViStatus _VI_FUNC rssgs_GetAttenuatorUpperRange (ViSession instrumentHandle,
                                    ViReal64* attenuatorUpperRange);

ViStatus _VI_FUNC rssgs_SetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViBoolean correctionState);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViBoolean *correctionState);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataCatalog (ViSession instrumentHandle,
                                                      ViString directoryPath,
                                                      ViInt32 arraySize,
                                                      ViChar catalogList[]);

ViStatus _VI_FUNC rssgs_SetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViString correctionTable);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViChar correctionTable[]);

ViStatus _VI_FUNC rssgs_SetUserCorrectionDataFrequencyValues (ViSession instrumentHandle,
                                                              ViInt32 arraySize,
                                                              ViReal64 frequencyValues[]);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataFrequencyValues (ViSession instrumentHandle,
                                                              ViInt32 arraySize,
                                                              ViReal64 frequencyValues[]);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataNumberofFrequencyValues (ViSession instrumentHandle,
                                                                      ViInt32 *numberOfFrequencyValues);

ViStatus _VI_FUNC rssgs_SetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 levelValues[]);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 levelValues[]);

ViStatus _VI_FUNC rssgs_GetUserCorrectionDataNumberofLevelValues (ViSession instrumentHandle,
                                                                  ViInt32 *numberOfLevelValues);

ViStatus _VI_FUNC rssgs_UserCorrectionDataDeleteTable (ViSession instrumentHandle,
                                                       ViString tableName);

ViStatus _VI_FUNC rssgs_GetUserCorrectionValue (ViSession instrumentHandle,
                                                ViReal64 *userCorrectionValue);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportListMode (ViSession instrumentHandle,
                                                           ViInt32 listMode);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportListMode (ViSession instrumentHandle,
                                                           ViInt32 *listMode);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportListFile (ViSession instrumentHandle,
                                                           ViString sourceFile);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportListFile (ViSession instrumentHandle,
                                                           ViInt32 arraySize,
                                                           ViChar sourceFile[]);

ViStatus _VI_FUNC rssgs_CorrectionImportExportExecute (ViSession instrumentHandle);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportASCIIFile (ViSession instrumentHandle,
                                                            ViString ASCIISourceFile);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportASCIIFile (ViSession instrumentHandle,
                                                            ViInt32 arraySize,
                                                            ViChar ASCIISourceFile[]);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportASCIIExtension (ViSession instrumentHandle,
                                                                 ViInt32 extension);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportASCIIExtension (ViSession instrumentHandle,
                                                                 ViInt32 *extension);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportASCIIColumnSeparator (ViSession instrumentHandle,
                                                                       ViInt32 separator);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportASCIIColumnSeparator (ViSession instrumentHandle,
                                                                       ViInt32 *separator);

ViStatus _VI_FUNC rssgs_SetCorrectionImportExportASCIIColumnDecimalSeparator (ViSession instrumentHandle,
                                                                              ViInt32 decimalSeparator);

ViStatus _VI_FUNC rssgs_GetCorrectionImportExportASCIIColumnDecimalSeparator (ViSession instrumentHandle,
                                                                              ViInt32 *decimalSeparator);

ViStatus _VI_FUNC rssgs_CorrectionImportExportCatalog (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViInt32 arraySize,
                                                       ViChar catalogList[]);

ViStatus _VI_FUNC rssgs_ConfigureIQ (ViSession instrumentHandle,
                        ViBoolean IQModulatorState,
                        ViBoolean IQWideband);
ViStatus _VI_FUNC rssgs_ConfigureIQImpairments (ViSession instrumentHandle,
                                   ViBoolean state, ViReal64 iOffset,
                                   ViReal64 qOffset,
                                   ViReal64 gainImbalance,
                                   ViReal64 quadratureOffset);
ViStatus _VI_FUNC rssgs_SetIQModulatorState (ViSession instrumentHandle,
                                ViBoolean IQModulatorState);
ViStatus _VI_FUNC rssgs_GetIQModulatorState (ViSession instrumentHandle,
                                ViBoolean* IQModulatorState);
ViStatus _VI_FUNC rssgs_SetIQImpairmentsState (ViSession instrumentHandle,
                                  ViBoolean state);
ViStatus _VI_FUNC rssgs_GetIQImpairmentsState (ViSession instrumentHandle,
                                  ViBoolean* state);
ViStatus _VI_FUNC rssgs_SetIQImpairmentsIOffset (ViSession instrumentHandle,
                                    ViReal64 iOffset);
ViStatus _VI_FUNC rssgs_GetIQImpairmentsIOffset (ViSession instrumentHandle,
                                    ViReal64* iOffset);
ViStatus _VI_FUNC rssgs_SetIQImpairmentsQOffset (ViSession instrumentHandle,
                                    ViReal64 qOffset);
ViStatus _VI_FUNC rssgs_GetIQImpairmentsQOffset (ViSession instrumentHandle,
                                    ViReal64* qOffset);
ViStatus _VI_FUNC rssgs_SetIQImpairmentsGainImbalance (ViSession instrumentHandle,
                                          ViReal64 gainImbalance);
ViStatus _VI_FUNC rssgs_GetIQImpairmentsGainImbalance (ViSession instrumentHandle,
                                          ViReal64* gainImbalance);
ViStatus _VI_FUNC rssgs_SetIQImpairmentsQuadratureOffset (ViSession instrumentHandle,
                                             ViReal64 quadratureOffset);
ViStatus _VI_FUNC rssgs_GetIQImpairmentsQuadratureOffset (ViSession instrumentHandle,
                                             ViReal64* quadratureOffset);
ViStatus _VI_FUNC rssgs_SetIQWideband (ViSession instrumentHandle,
                          ViBoolean IQWideband);
ViStatus _VI_FUNC rssgs_GetIQWideband (ViSession instrumentHandle,
                          ViBoolean* IQWideband);

ViStatus _VI_FUNC rssgs_SetIQCrestFactor (ViSession instrumentHandle,
                             ViReal64 crestFactor);

ViStatus _VI_FUNC rssgs_GetIQCrestFactor (ViSession instrumentHandle,
                             ViReal64 *crestFactor);

ViStatus _VI_FUNC rssgs_LockInstrument (ViSession instrumentHandle, ViInt32 lockID,
                           ViInt32* result);
ViStatus _VI_FUNC rssgs_UnlockInstrument (ViSession instrumentHandle,
                             ViInt32 lockID);


ViStatus _VI_FUNC rssgs_EXTensionInstNames (ViSession instrumentHandle, 
                               ViInt32 arraySize, 
                               ViChar _VI_FAR symbolicNames[]);

ViStatus _VI_FUNC rssgs_EXTensionInstLanNames (ViSession instrumentHandle, 
                               ViInt32 arraySize, 
                               ViChar _VI_FAR lanNames[]);

ViStatus _VI_FUNC rssgs_ExtensionInstHardwareChannels (ViSession instrumentHandle,
                               ViInt32 arraySize,
                               ViInt32 hardwareChannel[],
                               ViInt32 *returnedValues);

ViStatus _VI_FUNC rssgs_ExtensionInstSerialNumbers (ViSession instrumentHandle,
                                       ViInt32 arraySize,
                                       ViInt32 serialNumbers[],
                                       ViInt32 *returnedValues);

ViStatus _VI_FUNC rssgs_SetExtensionInstScanState (ViSession instrumentHandle, 
                                      ViBoolean state);

ViStatus _VI_FUNC rssgs_GetExtensionInstScanState (ViSession instrumentHandle, 
                                      ViBoolean *state);

ViStatus _VI_FUNC rssgs_GetExtensionRemoteState (ViSession instrumentHandle, 
                                      ViBoolean *state);

ViStatus _VI_FUNC rssgs_GetExtensionBusyState (ViSession instrumentHandle, 
                                    ViBoolean *state);

ViStatus _VI_FUNC rssgs_SetExtensionSelect (ViSession instrumentHandle,
                               ViInt32 nSelIndex);


ViStatus _VI_FUNC rssgs_GetExtensionSelect (ViSession instrumentHandle,
                               ViInt32* nSelIndex);

ViStatus _VI_FUNC rssgs_ExtensionSend (ViSession instrumentHandle,
                                     ViString scpicommand);
ViStatus _VI_FUNC rssgs_ExtensionQuery (ViSession instrumentHandle,
                           ViString scpicommand,
                           ViInt32 arraySize,
                           ViChar _VI_FAR reply[]);


ViStatus _VI_FUNC rssgs_CALibrationAll (ViSession instrumentHandle, ViInt32 timeout,
                           ViInt32* result);
ViStatus _VI_FUNC rssgs_CALibrationLevel (ViSession instrumentHandle,
                             ViInt32 timeout, ViInt32* result);
ViStatus _VI_FUNC rssgs_CALibrationSynthesis (ViSession instrumentHandle,
                                 ViInt32 timeout, ViInt32* result);
ViStatus _VI_FUNC rssgs_CALibrationIQModulator (ViSession instrumentHandle,
                                   ViInt32 timeout, ViInt32* result);
ViStatus _VI_FUNC rssgs_CALibrationIQModulatorForCurrentFrequency
(ViSession instrumentHandle, ViInt32 timeout, ViInt32* result);


ViStatus _VI_FUNC rssgs_GetCalibrationIQTemperature (ViSession instrumentHandle,
                                        ViReal64 *temperature);

ViStatus _VI_FUNC rssgs_GetCalibrationLevelTemperature (ViSession instrumentHandle,
                                        ViReal64 *temperature);
ViStatus _VI_FUNC rssgs_GetCalibrationSynthesisTemperature (ViSession instrumentHandle,
                                           ViReal64 *temperature);

ViStatus _VI_FUNC rssgs_SetCalibrationExtensionOnlyState (ViSession instrumentHandle, 
                                      ViBoolean state);

ViStatus _VI_FUNC rssgs_GetCalibrationExtensionOnlyState (ViSession instrumentHandle, 
                                      ViBoolean *state);

ViStatus _VI_FUNC rssgs_GetTestAllSignalConnections (ViSession instrumentHandle,
                                                     ViInt32 *testSignalConnections);

ViStatus _VI_FUNC rssgs_GetTestRFSignalConnection (ViSession instrumentHandle,
                                                   ViInt32 *testRFSignalConnection);

ViStatus _VI_FUNC rssgs_confPulm (ViSession instrumentHandle, ViBoolean state,
                     ViInt32 source, ViInt32 polarity,
                     ViBoolean pulseGeneratorState,
                     ViReal64 pulsePeriod, ViReal64 pulseWidth,
                     ViReal64 pulseDelay, ViInt32 doublePulseMode,
                     ViReal64 doublePulseWidth,
                     ViReal64 doublePulseDelay, ViInt32 triggerMode);

ViStatus _VI_FUNC rssgs_SetPULMState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssgs_GetPULMState (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssgs_SetPULMPolarity (ViSession instrumentHandle,
                            ViInt32 polarity);
ViStatus _VI_FUNC rssgs_GetPULMPolarity (ViSession instrumentHandle,
                            ViPInt32 polarity);
ViStatus _VI_FUNC rssgs_SetPULMSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssgs_GetPULMSource (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rssgs_SetPULMPeriod (ViSession instrumentHandle,
                          ViReal64 pulsePeriod);
ViStatus _VI_FUNC rssgs_GetPULMPeriod (ViSession instrumentHandle,
                          ViPReal64 pulsePeriod);
ViStatus _VI_FUNC rssgs_SetPULMWidth (ViSession instrumentHandle,
                         ViReal64 pulseWidth);
ViStatus _VI_FUNC rssgs_GetPULMWidth (ViSession instrumentHandle,
                         ViPReal64 pulseWidth);
ViStatus _VI_FUNC rssgs_SetPULMDelay (ViSession instrumentHandle,
                         ViReal64 pulseDelay);
ViStatus _VI_FUNC rssgs_GetPULMDelay (ViSession instrumentHandle,
                         ViPReal64 pulseDelay);
ViStatus _VI_FUNC rssgs_SetPULMDoubleWidth (ViSession instrumentHandle,
                               ViReal64 doublePulseWidth);
ViStatus _VI_FUNC rssgs_GetPULMDoubleWidth (ViSession instrumentHandle,
                               ViPReal64 doublePulseWidth);
ViStatus _VI_FUNC rssgs_SetPULMDoubleDelay (ViSession instrumentHandle,
                               ViReal64 doublePulseDelay);
ViStatus _VI_FUNC rssgs_GetPULMDoubleDelay (ViSession instrumentHandle,
                               ViPReal64 doublePulseDelay);
ViStatus _VI_FUNC rssgs_SetPULMTriggerMode (ViSession instrumentHandle,
                               ViInt32 triggerMode);
ViStatus _VI_FUNC rssgs_GetPULMTriggerMode (ViSession instrumentHandle,
                               ViPInt32 triggerMode);
ViStatus _VI_FUNC rssgs_SetPULMExternalTriggerInputImpedance
(ViSession instrumentHandle, ViInt32 externalInputImpedance);
ViStatus _VI_FUNC rssgs_GetPULMExternalTriggerInputImpedance
(ViSession instrumentHandle, ViPInt32 externalInputImpedance);
ViStatus _VI_FUNC rssgs_SetPULMExternalTriggerSlope (ViSession instrumentHandle,
                                        ViInt32 externalTriggerSlope);
ViStatus _VI_FUNC rssgs_GetPULMExternalTriggerSlope (ViSession instrumentHandle,
                                        ViPInt32 externalTriggerSlope);
ViStatus _VI_FUNC rssgs_SetPULMGateInputPolarity (ViSession instrumentHandle,
                                     ViInt32 gateInputPolarity);
ViStatus _VI_FUNC rssgs_GetPULMGateInputPolarity (ViSession instrumentHandle,
                                     ViPInt32 gateInputPolarity);
ViStatus _VI_FUNC rssgs_SetPULMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetPULMMode (ViSession instrumentHandle, ViPInt32 mode);




ViStatus _VI_FUNC rssgs_GetNetworkSystemSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_GetNetworkMACAddress (ViSession instrumentHandle,
                                 ViInt32 arraySize,
                                 ViChar _VI_FAR MACAddress[]);

ViStatus _VI_FUNC rssgs_ConfigureNetworkIP (ViSession instrumentHandle,
                               ViInt32 addressMode, ViString IPAddress,
                               ViString subnetMask,
                               ViString defaultGateway);

ViStatus _VI_FUNC rssgs_NetworkRestart (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_GetNetworkResource (ViSession instrumentHandle,
                               ViUInt32 arraySize,
                               ViChar _VI_FAR resource[]);
ViStatus _VI_FUNC rssgs_GetNetworkConfigurationState (ViSession instrumentHandle,
                                         ViBoolean* configuration);
ViStatus _VI_FUNC rssgs_SetNetworkCommonHostname (ViSession instrumentHandle,
                                     ViString hostname);
ViStatus _VI_FUNC rssgs_GetNetworkCommonHostname (ViSession instrumentHandle,
                                     ViInt32 arraySize,
                                     ViChar _VI_FAR hostname[]);
ViStatus _VI_FUNC rssgs_SetNetworkIPAddressMode (ViSession instrumentHandle,
                                    ViInt32 addressMode);
ViStatus _VI_FUNC rssgs_GetNetworkIPAddressMode (ViSession instrumentHandle,
                                    ViInt32* addressMode);
ViStatus _VI_FUNC rssgs_SetNetworkIPAddress (ViSession instrumentHandle,
                                ViString IPAddress);
ViStatus _VI_FUNC rssgs_GetNetworkIPAddress (ViSession instrumentHandle,
                                ViInt32 arraySize,
                                ViChar _VI_FAR IPAddress[]);
ViStatus _VI_FUNC rssgs_SetNetworkIPSubnetMask (ViSession instrumentHandle,
                                   ViString subnetMask);
ViStatus _VI_FUNC rssgs_GetNetworkIPSubnetMask (ViSession instrumentHandle,
                                   ViInt32 arraySize,
                                   ViChar _VI_FAR subnetMask[]);
ViStatus _VI_FUNC rssgs_SetNetworkIPDefaultGateway (ViSession instrumentHandle,
                                       ViString defaultGateway);
ViStatus _VI_FUNC rssgs_GetNetworkIPDefaultGateway (ViSession instrumentHandle,
                                       ViInt32 arraySize,
                                       ViChar _VI_FAR defaultGateway[]);

ViStatus _VI_FUNC rssgs_AcceptNetworkIPSettings (ViSession instrumentHandle);

ViStatus _VI_FUNC rssgs_SetSerialBaudRate (ViSession instrumentHandle,
                              ViInt32 baudrate);

ViStatus _VI_FUNC rssgs_GetSerialBaudRate (ViSession instrumentHandle,
                              ViInt32* baudrate);

ViStatus _VI_FUNC rssgs_SetSerialParity (ViSession instrumentHandle,
                            ViInt32 parity);

ViStatus _VI_FUNC rssgs_GetSerialParity (ViSession instrumentHandle,
                            ViInt32* parity);

ViStatus _VI_FUNC rssgs_SetSerialStopBits (ViSession instrumentHandle,
                              ViInt32 stopbits);

ViStatus _VI_FUNC rssgs_GetSerialStopBits (ViSession instrumentHandle,
                              ViInt32* stopbits);


ViStatus _VI_FUNC rssgs_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_EventStatusEnable (ViSession instrumentHandle,
                              ViInt32 registerValue);
ViStatus _VI_FUNC rssgs_EventStatusQuery (ViSession instrumentHandle,
                             ViInt32* registerValue);
ViStatus _VI_FUNC rssgs_IdentificationQuery (ViSession instrumentHandle,
                                ViChar _VI_FAR instrumentIdentification[]);
ViStatus _VI_FUNC rssgs_IndividualStatusQuery (ViSession instrumentHandle,
                                  ViInt32* ISTFlag);
ViStatus _VI_FUNC rssgs_OperationComplete (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_OperationCompleteQuery (ViSession instrumentHandle,
                                   ViInt32* OPCState);
ViStatus _VI_FUNC rssgs_OptionIdentificationQuery (ViSession instrumentHandle,
                                      ViChar _VI_FAR optionIdentification[]);
ViStatus _VI_FUNC rssgs_ParallelPollRegisterEnable (ViSession instrumentHandle,
                                       ViInt32 registerValue);
ViStatus _VI_FUNC rssgs_ParallelPollRegisterQuery (ViSession instrumentHandle,
                                      ViInt32* registerValue);
ViStatus _VI_FUNC rssgs_PowerOnStatusClear (ViSession instrumentHandle,
                               ViInt32 registerValue);
ViStatus _VI_FUNC rssgs_PowerOnStatusClearQuery (ViSession instrumentHandle,
                                    ViInt32* registerValue);
ViStatus _VI_FUNC rssgs_Recall (ViSession instrumentHandle,
                   ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssgs_Save (ViSession instrumentHandle, ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssgs_ServiceRequestEnable (ViSession instrumentHandle,
                                 ViInt32 registerValue);
ViStatus _VI_FUNC rssgs_ServiceRequestEnableQuery (ViSession instrumentHandle,
                                      ViInt32* registerValue);
ViStatus _VI_FUNC rssgs_StatusByteQuery (ViSession instrumentHandle,
                            ViInt32* statusByte);
ViStatus _VI_FUNC rssgs_Trigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_TriggerWaitOPC (ViSession instrumentHandle,
                           ViInt32 timeout);
ViStatus _VI_FUNC rssgs_SetTrigConnnectorOpMode (ViSession instrumentHandle,
                                    ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetTrigConnnectorOpMode (ViSession instrumentHandle,
                                    ViInt32* mode);
ViStatus _VI_FUNC rssgs_SelfTestQuery (ViSession instrumentHandle,
                          ViInt32* errorCode);
ViStatus _VI_FUNC rssgs_WaittoContinue (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_DIAGnosticTestPoints (ViSession instrumentHandle,
                                 ViInt32 arraySize,
                                 ViChar _VI_FAR testPoints[]);
ViStatus _VI_FUNC rssgs_DIAGnosticTestPointVoltage (ViSession instrumentHandle,
                                       ViString testPointName,
                                       ViReal64* measuredVoltage);
ViStatus _VI_FUNC rssgs_DIAGnosticGetMemoryContent (ViSession instrumentHandle,
                                       ViInt32 bar, ViInt32 adress,
                                       ViInt32* data);
ViStatus _VI_FUNC rssgs_DIAGnosticSetMemoryContent (ViSession instrumentHandle,
                                       ViInt32 bar, ViInt32 adress,
                                       ViInt32 data);
ViStatus _VI_FUNC rssgs_MemoryHeapFree (ViSession instrumentHandle,
                        ViInt32* TotalPhysMemKb,
                        ViInt32* ApplicMemKb,
                        ViInt32* HeapUsedKb,
                        ViInt32* HeapAvailableKb);

ViStatus _VI_FUNC rssgs_MMEMoryChangeDefaultDrive (ViSession instrumentHandle,
                                      ViString drive);
ViStatus _VI_FUNC rssgs_MMEMoryGetDefaultDrive (ViSession instrumentHandle,
                                   ViInt32 arraySize,
                                   ViChar _VI_FAR drive[]);
ViStatus _VI_FUNC rssgs_MMEMoryChangeDirectory (ViSession instrumentHandle,
                                   ViString directoryName);
ViStatus _VI_FUNC rssgs_MMEMoryGetDirectory (ViSession instrumentHandle,
                                ViInt32 arraySize,
                                ViChar _VI_FAR directory[]);
ViStatus _VI_FUNC rssgs_MMEMoryCopy (ViSession instrumentHandle,
                        ViString sourcePath, ViString destinationPath);
ViStatus _VI_FUNC rssgs_MMEMoryBlockDataWrite (ViSession instrumentHandle,
                                  ViString fileName,
                                  ViInt32 binaryBlockLength,
                                  ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssgs_MMEMoryBlockDataRead (ViSession instrumentHandle,
                                 ViString fileName,
                                 ViInt32 binaryBlockLength,
                                 ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssgs_MMEMoryCatalog (ViSession instrumentHandle,
                           ViString directoryPath, ViInt32 arraySize,
                           ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssgs_MMEMoryCatalogLength (ViSession instrumentHandle,
                                 ViString directoryPath,
                                 ViInt32* length);

ViStatus _VI_FUNC rssgs_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
                                    ViString directoryPath,
                                    ViInt32 arraySize,
                                    ViChar _VI_FAR catalogList[]);

ViStatus _VI_FUNC rssgs_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
                                 ViString directoryPath,
                                 ViInt32* length);

ViStatus _VI_FUNC rssgs_MMEMoryDelete (ViSession instrumentHandle,
                          ViString fileName);
ViStatus _VI_FUNC rssgs_MMEMoryMakeDirectory (ViSession instrumentHandle,
                                 ViString directoryName);
ViStatus _VI_FUNC rssgs_MMEMoryMove (ViSession instrumentHandle,
                        ViString fileSource, ViString fileDestination);
ViStatus _VI_FUNC rssgs_MMEMoryRemoveDirectory (ViSession instrumentHandle,
                                   ViString directoryName);

ViStatus _VI_FUNC rssgs_MMEMoryLoadState (ViSession instrumentHandle,
                             ViInt32 storage,  
                             ViString fileName);
                             
ViStatus _VI_FUNC rssgs_MMEMoryStoreState (ViSession instrumentHandle,
                             ViInt32 storage,  
                             ViString fileName);

ViStatus _VI_FUNC rssgs_TESTDirect (ViSession instrumentSession, ViInt32 component,
                       ViInt32 address, ViInt32* data);
ViStatus _VI_FUNC rssgs_TESTVoltage (ViSession instrumentHandle, ViInt32* result);
ViStatus _VI_FUNC rssgs_TESTSelftestResult (ViSession instrumentHandle,
                               ViInt32* result);
ViStatus _VI_FUNC rssgs_TESTSelftestStart (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_TestSpeed (ViSession instrumentHandle, ViReal64 frequency,
                      ViReal64 level);

ViStatus _VI_FUNC rssgs_SetTestKeyboardState (ViSession instrumentHandle,
                                ViBoolean state);

ViStatus _VI_FUNC rssgs_GetTestKeyboardState (ViSession instrumentHandle,
                                ViBoolean *state);

ViStatus _VI_FUNC rssgs_SetRegister (ViSession instrumentHandle,
                        ViInt32 registerGroup, ViInt32 registerType,
                        ViInt32 value);
ViStatus _VI_FUNC rssgs_GetRegister (ViSession instrumentHandle,
                        ViInt32 registerGroup, ViInt32 registerType,
                        ViInt32* value);
ViStatus _VI_FUNC rssgs_STATusPRESet (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_SYSTemErrorQueueAll (ViSession instrumentHandle,
                                ViInt32 arraySize,
                                ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rssgs_SYSTemErrorQueueCodeAll (ViSession instrumentHandle,
                                    ViInt32 arraySize,
                                    ViChar _VI_FAR errorQueueCode[]);
ViStatus _VI_FUNC rssgs_SYSTemErrorQueueCodeNext (ViSession instrumentHandle,
                                     ViInt32* errorQueueCodeNext);
ViStatus _VI_FUNC rssgs_SYSTemErrorQueueCount (ViSession instrumentHandle,
                                  ViInt32* errorQueueCount);
ViStatus _VI_FUNC rssgs_SYSTemStaticErrorQueue (ViSession instrumentHandle,
                                   ViInt32 arraySize,
                                   ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rssgs_SYSTemUSBResource (ViSession instrumentHandle,
                              ViUInt32 arraySize,
                              ViChar _VI_FAR USBResource[]);

ViStatus _VI_FUNC rssgs_SYSTemSocketResource (ViSession instrumentHandle,
                              ViUInt32 arraySize,
                              ViChar _VI_FAR SocketResource[]);

ViStatus _VI_FUNC rssgs_SYSTemPCIeResource (ViSession instrumentHandle,
                              ViUInt32 arraySize,
                              ViChar _VI_FAR PCIeResource[]);

ViStatus _VI_FUNC rssgs_SYSTemHislipResource (ViSession instrumentHandle,
                               ViUInt32 arraySize,
                               ViChar _VI_FAR HislipResource[]);

ViStatus _VI_FUNC rssgs_SYSTemSerialResource (ViSession instrumentHandle,
                                 ViUInt32 arraySize,
                                 ViChar _VI_FAR SerialResource[]);


ViStatus _VI_FUNC rssgs_SYSTemRestoreFactorySettings (ViSession instrumentHandle);

ViStatus _VI_FUNC rssgs_SetSYSTemEcoMode (ViSession instrumentHandle,
                             ViInt32 mode);

ViStatus _VI_FUNC rssgs_GetSYSTemEcoMode (ViSession instrumentHandle,
                             ViInt32 *mode);

ViStatus _VI_FUNC rssgs_SetSYSTemProtect (ViSession instrumentHandle,
                             ViInt32 protectionLevel,
                             ViBoolean protection, ViString password);
ViStatus _VI_FUNC rssgs_GetSYSTemProtect (ViSession instrumentHandle,
                             ViInt32 protectionLevel,
                             ViBoolean* protection);
ViStatus _VI_FUNC rssgs_GetSYSTemVersion (ViSession instrumentHandle,
                             ViChar _VI_FAR SCPIVersion[]);
ViStatus _VI_FUNC rssgs_GetSYSTemStartupStatus (ViSession instrumentHandle,
                                   ViInt32* startupComplete);
ViStatus _VI_FUNC rssgs_SetSYSTemTerminatorMode (ViSession instrumentHandle,
                                    ViInt32 mode);
ViStatus _VI_FUNC rssgs_GetSYSTemTerminatorMode (ViSession instrumentHandle,
                                    ViInt32* mode);
ViStatus _VI_FUNC rssgs_GetSYSTemHwAssemblyNames (ViSession instrumentHandle,
                                     ViInt32 assemblyIndex,
                                     ViInt32 arraySize,
                                     ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemHwPartNumbers (ViSession instrumentHandle,
                                   ViInt32 assemblyIndex,
                                   ViInt32 arraySize,
                                   ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemHwRevisions (ViSession instrumentHandle,
                                 ViInt32 assemblyIndex,
                                 ViInt32 arraySize,
                                 ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemHwSerialNumbers (ViSession instrumentHandle,
                                     ViInt32 assemblyIndex,
                                     ViInt32 arraySize,
                                     ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemSwOptionDesignations (ViSession instrumentHandle,
                                          ViInt32 optionIndex,
                                          ViInt32 arraySize,
                                          ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemSwOptionNames (ViSession instrumentHandle,
                                   ViInt32 optionIndex,
                                   ViInt32 arraySize,
                                   ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemSwOptionExpirations (ViSession instrumentHandle,
                                         ViInt32 optionIndex,
                                         ViInt32 arraySize,
                                         ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rssgs_GetSYSTemSwOptionLicenses (ViSession instrumentHandle,
                                      ViInt32 optionIndex,
                                      ViInt32 arraySize,
                                      ViChar _VI_FAR list[]);

ViStatus _VI_FUNC rssgs_GetSYSTemOperatingSystem (ViSession instrumentHandle,
                                     ViInt32 arraySize,
                                     ViChar osname[]);

ViStatus _VI_FUNC rssgs_GetSYSTemUserMemoryPath (ViSession instrumentHandle,
                                    ViInt32 arraySize,
                                    ViChar path[]);

ViStatus _VI_FUNC rssgs_SetAngleUnits (ViSession instrumentHandle,
                          ViInt32 angleUnits);
ViStatus _VI_FUNC rssgs_GetAngleUnits (ViSession instrumentHandle,
                          ViInt32* angleUnits);
ViStatus _VI_FUNC rssgs_SetPowerUnits (ViSession instrumentHandle,
                          ViInt32 powerUnits);
ViStatus _VI_FUNC rssgs_GetPowerUnits (ViSession instrumentHandle,
                          ViInt32* powerUnits);
ViStatus _VI_FUNC rssgs_SetFormatData (ViSession instrumentHandle, ViInt32 format);
ViStatus _VI_FUNC rssgs_GetFormatData (ViSession instrumentHandle, ViInt32* format);

ViStatus _VI_FUNC rssgs_SetFormatStatusRegisterData (ViSession instrumentHandle,
                                                     ViInt32 format);

ViStatus _VI_FUNC rssgs_GetFormatStatusRegisterData (ViSession instrumentHandle,
                                                     ViInt32 *format);

ViStatus _VI_FUNC rssgs_SetFormatByteOrder (ViSession instrumentHandle,
                                            ViInt32 byteOrder);

ViStatus _VI_FUNC rssgs_GetFormatByteOrder (ViSession instrumentHandle,
                                            ViInt32 *byteOrder);

ViStatus _VI_FUNC rssgs_errorCheckState (ViSession instrumentHandle,
                            ViBoolean stateChecking);
ViStatus _VI_FUNC rssgs_optionCheckState (ViSession instrumentHandle,
                             ViBoolean stateChecking);
ViStatus _VI_FUNC rssgs_setCheckRange (ViSession instrumentHandle,
                          ViBoolean rangeChecking);
ViStatus _VI_FUNC rssgs_writeInstrData (ViSession instrumentHandle,
                           ViString writeBuffer);
ViStatus _VI_FUNC rssgs_readInstrData (ViSession instrumentHandle,
                          ViInt32 numberBytesToRead,
                          ViChar _VI_FAR readBuffer[],
                          ViInt32* numBytesRead);
ViStatus _VI_FUNC rssgs_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_Clear (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_self_test (ViSession instrumentHandle,
                      ViInt16* selfTestResult,
                      ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssgs_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssgs_error_message (ViSession instrumentHandle,
                          ViStatus statusCode,
                          ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssgs_revision_query (ViSession instrumentHandle,
                           ViChar _VI_FAR instrumentDriverRevision[],
                           ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssgs_enumerate_pcie_devices (ViInt32 vendorID, ViInt32 deviceID,
                                   ViInt32 _VI_FAR serialNumbers[],
                                   ViInt32* arraySize);
ViStatus _VI_FUNC rssgs_enumerate_socket_devices (ViPString *info, ViPInt32 infoCount);                                               
ViStatus _VI_FUNC rssgs_delay (ViSession instrumentHandle, ViReal64 seconds);
ViStatus _VI_FUNC rssgs_close (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_Restart (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_Standby(ViSession instrumentHandle);
ViStatus _VI_FUNC rssgs_getAttribute(ViSession instrumentHandle, ViAttr attribute, void* value);
ViStatus _VI_FUNC rssgs_setAttribute(ViSession instrumentHandle, ViAttr attribute, ViAttrState value);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
